@@ -1,12 +1,9 @@
-from enum import Enum
-from os import name, wait
+from os import wait
 from selve.device import Device
 from selve.communication import Command, CommandSingle
-from selve.protocol import CommunicationType, DeviceClass, MethodCall, ScanState, SensorState, ServiceState, TeachState, lightDigital, rainDigital, tempDigital, windDigital
+from selve.protocol import CommunicationType, DeviceClass, ScanState, SensorState, TeachState, lightDigital, rainDigital, tempDigital, windDigital
 from selve.protocol import ParameterType
-from selve.protocol import DeviceType
-from selve.protocol import CommandType
-from selve.commands import Commands, CommeoCommandCommand, CommeoDeviceCommand, CommeoEventCommand, CommeoGroupCommand, CommeoParamCommand, CommeoSenSimCommand, CommeoSenderCommand, CommeoSensorCommand, CommeoServiceCommand
+from selve.commands import CommeoSensorCommand
 from selve.utils import singlemask
 from selve.utils import true_in_list
 from selve.utils import b64bytes_to_bitlist
